@@ -2,7 +2,7 @@ package XML::Grammar::Screenplay::FromProto;
 
 use XML::Writer;
 
-use Moose;
+use Mouse;
 
 extends("XML::Grammar::FictionBase::TagsTree2XML");
 
@@ -15,11 +15,11 @@ text representing a screenplay to an XML format.
 
 =head1 VERSION
 
-Version 0.8.1
+Version 0.9.0
 
 =cut
 
-our $VERSION = '0.8.1';
+our $VERSION = '0.9.0';
 
 =head2 new()
 
@@ -38,7 +38,7 @@ sub _init
 
     local $Parse::RecDescent::skip = "";
 
-    my $parser_class = 
+    my $parser_class =
         ($args->{parser_class} || "XML::Grammar::Screenplay::FromProto::Parser::QnD");
 
     $self->_parser(
@@ -54,8 +54,6 @@ Converts the file $path_to_file to XML and returns it.
 
 =cut
 
-use Data::Dumper;
-
 sub _output_tag
 {
     my ($self, $args) = @_;
@@ -72,7 +70,7 @@ sub _output_tag_with_childs
 {
     my ($self, $args) = @_;
 
-    return 
+    return
         $self->_output_tag({
             %$args,
             'in' => sub {
@@ -195,7 +193,7 @@ sub _write_scene
     my $scene = $args->{scene};
 
     my $tag = $scene->name;
-    
+
     if (($tag eq "s") || ($tag eq "scene"))
     {
         my $id = $scene->lookup_attr("id");
@@ -236,7 +234,7 @@ sub _read_file
         $contents = <$in>;
     }
     close($in);
-    
+
     return $contents;
 }
 
@@ -250,6 +248,8 @@ sub _calc_tree
     return $self->_parser->process_text($self->_read_file($filename));
 }
 
+has '_buffer' => (is => "rw");
+
 sub convert
 {
     my ($self, $args) = @_;
@@ -257,9 +257,9 @@ sub convert
     # These should be un-commented for debugging.
     # local $::RD_HINT = 1;
     # local $::RD_TRACE = 1;
-    
+
     # We need this so P::RD won't skip leading whitespace at lines
-    # which are siginificant.  
+    # which are siginificant.
 
     my $tree = $self->_calc_tree($args);
 
@@ -270,9 +270,9 @@ sub convert
 
     my $buffer = "";
     $self->_buffer(\$buffer);
-    
+
     my $writer = XML::Writer->new(
-        OUTPUT => $self->_buffer(), 
+        OUTPUT => $self->_buffer(),
         ENCODING => "utf-8",
         NAMESPACES => 1,
         PREFIX_MAP =>
@@ -296,7 +296,7 @@ sub convert
     $writer->endTag();
 
     $writer->endTag();
-    
+
     return ${$self->_buffer()};
 }
 
